@@ -6,15 +6,14 @@
 @synopsis: 角色API
 @created_time: 2022/9/2 15:38
 """
-from xj_role.services.role_service import RoleService
+from xj_role.services.role_service import RoleService, RoleTreeService
 from ..utils.model_handle import *
 
 
 class RoleAPIView():
     def tree(self):
         params = parse_data(self)
-        role_id = params.get("role_id", 0)
-        res, err = RoleService.role_tree(role_id)
+        res, err = RoleTreeService.role_tree(params.get("role_id", 0))
         if err:
             return util_response(err=1000, msg=err)
         return util_response(data=res)
